Class: Boxxspring::Parser
- Inherits:
-
Object
- Object
- Boxxspring::Parser
- Defined in:
- lib/boxxspring/parser.rb
Instance Method Summary collapse
- #associations ⇒ Object
-
#initialize(content = {}) {|_self| ... } ⇒ Parser
constructor
A new instance of Parser.
- #key ⇒ Object
- #keys ⇒ Object
- #name ⇒ Object
- #resource_associations_by(name, key) ⇒ Object
- #resource_attribute_index ⇒ Object
- #resource_by(name, key) ⇒ Object
- #resources ⇒ Object
- #type_name ⇒ Object
- #type_name?(name) ⇒ Boolean
Constructor Details
#initialize(content = {}) {|_self| ... } ⇒ Parser
Returns a new instance of Parser.
5 6 7 8 |
# File 'lib/boxxspring/parser.rb', line 5 def initialize( content = {} ) @content = content yield self if block_given? end |
Instance Method Details
#associations ⇒ Object
36 37 38 39 40 |
# File 'lib/boxxspring/parser.rb', line 36 def associations @content.include?( '$associations' ) ? @content[ '$associations' ] : nil end |
#key ⇒ Object
26 27 28 |
# File 'lib/boxxspring/parser.rb', line 26 def key 'id' end |
#keys ⇒ Object
30 31 32 33 34 |
# File 'lib/boxxspring/parser.rb', line 30 def keys @content.include?( '$this' ) ? @content[ '$this' ][ 'ids' ] : nil end |
#name ⇒ Object
10 11 12 13 14 |
# File 'lib/boxxspring/parser.rb', line 10 def name @content.include?( '$this' ) ? @content[ '$this' ][ 'name' ] : nil end |
#resource_associations_by(name, key) ⇒ Object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/boxxspring/parser.rb', line 85 def resource_associations_by( name, key ) result = Hash.new { | hash, key | hash[ key ] = [] } associations = self.associations if associations && associations.include?( name ) association = associations[ name ].detect do | association | association[ 'id' ] == key end if association.present? association.each do | key, value | unless key == 'id' result[ key ] = value.map do | associated_id | self.resource_by( key, associated_id ) end result[ key ].compact! end end end end result end |
#resource_attribute_index ⇒ Object
106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/boxxspring/parser.rb', line 106 def resource_attribute_index @resource_attribute_index ||= begin index = Hash.new { | hash, key | hash[ key ] = {} } @content.each do | key, resources_attributes | unless key[0] == '$' resources_attributes.each do | resource_attributes | index[ key ][ resource_attributes[ 'id' ] ] = resource_attributes end end end index end end |
#resource_by(name, key) ⇒ Object
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/boxxspring/parser.rb', line 50 def resource_by( name, key ) @resources_index ||= Hash.new { | hash, key | hash[ key ] = {} } @resource_index_mutex ||= Hash.new { | hash, key | hash[ key ] = [] } @resources_index[ name ][ key ] ||= begin # lock the resource index for this name/key combination # note: this prevents boxxspring objects that are associated with # themselves from causing a stack overflow return nil if @resource_index_mutex[ name ].include?( key ) @resource_index_mutex[ name ].push( key ) result = nil resource_attributes = resource_attribute_index[ name ][ key ] if resource_attributes.present? type_name = resource_attributes[ 'type_name' ] || self.type_name klass = Boxxspring.const_get( type_name.camelize ) rescue nil if klass.present? result = klass.new( resource_attributes, self.resource_associations_by( name, key ) ) end end # unlock the resource index for this name/key combination @resource_index_mutex[ name ].delete( key ) result end end |
#resources ⇒ Object
42 43 44 45 46 47 48 |
# File 'lib/boxxspring/parser.rb', line 42 def resources result = nil unless self.name.blank? result = self.keys.map { | key | self.resource_by( name, key ) } end result end |
#type_name ⇒ Object
16 17 18 19 20 |
# File 'lib/boxxspring/parser.rb', line 16 def type_name @content.include?( '$this' ) ? @content[ '$this' ][ 'type_name' ] : nil end |
#type_name?(name) ⇒ Boolean
22 23 24 |
# File 'lib/boxxspring/parser.rb', line 22 def type_name?( name ) self.type_name == name.to_s end |